==> haskell-crypto-api-tests-0.3-10-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-api-tests.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-api-tests
version: 0.3
id: crypto-api-tests-0.3-2Wc7MaCxpgTAy5ZOOziDwC
key: crypto-api-tests-0.3-2Wc7MaCxpgTAy5ZOOziDwC
license: BSD-3-Clause
copyright: Thomas DuBuisson <thomas.dubuisson@gmail.com>
maintainer: Thomas DuBuisson <thomas.dubuisson@gmail.com>
author: Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability: stable
homepage: http://trac.haskell.org/crypto-api/wiki
synopsis: A test framework and KATs for cryptographic operations.
description:
    A test framework for hash and cipher operations using
    the crypto-api interface.  Known answer tests (KATs)
    for common cryptographic algorithms are included.
    Patches welcome (both adding KATs for more algorithms
    or property tests for classes of algorithms).
category: Data, Cryptography
abi: 87f57de01ea06375bfd91dbc5cee9caf
exposed: True
exposed-modules:
    Test.AES Test.Crypto Test.HMAC Test.MD5 Test.ParseNistKATs Test.SHA
    Test.TwoFish
hidden-modules: Paths_crypto_api_tests
import-dirs: /usr/lib/ghc-8.4.3/site-local/crypto-api-tests-0.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/crypto-api-tests-0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/crypto-api-tests-0.3
hs-libraries: HScrypto-api-tests-0.3-2Wc7MaCxpgTAy5ZOOziDwC
depends:
    HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr base-4.11.1.0
    bytestring-0.10.8.2 cereal-0.5.7.0-GeNBgd8Wa452X4EoKnwsnC
    crypto-api-0.13.3-9u8sDwmn8dvFreHHUkKG0l directory-1.3.1.5
    filepath-1.4.2 test-framework-0.8.2.0-Goo1lQ5v8lSKQXzKjc8cO4
    test-framework-hunit-0.3.0.2-2cuZrcC4fpi8ZHxh6Q4D1X
    test-framework-quickcheck2-0.3.0.5-HOPuSahD2LU2AFVRjsBcKR
abi-depends: HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx=6ff9610fd5e59ec310c47074d0590847
             QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=59a035869ce3bae16d8c8360447f600f
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             cereal-0.5.7.0-GeNBgd8Wa452X4EoKnwsnC=5e7d9231d9563e623638bef60db7e501
             crypto-api-0.13.3-9u8sDwmn8dvFreHHUkKG0l=04b47272348e9aa5648e546d18028ecd
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             test-framework-0.8.2.0-Goo1lQ5v8lSKQXzKjc8cO4=64a691e8d693925c03bbca87367ae847
             test-framework-hunit-0.3.0.2-2cuZrcC4fpi8ZHxh6Q4D1X=47b4f9d45cd39006a0ceb6cbdc059e99
             test-framework-quickcheck2-0.3.0.5-HOPuSahD2LU2AFVRjsBcKR=4500d7893d601963e358f7ca09ce1d18
haddock-interfaces: /usr/share/doc/haskell-crypto-api-tests/html/crypto-api-tests.haddock
haddock-html: /usr/share/doc/haskell-crypto-api-tests/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-api-tests-0.3-11-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-api-tests.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-api-tests
version: 0.3
id: crypto-api-tests-0.3-BEaiJn80LoQJ7APE3vN17b
key: crypto-api-tests-0.3-BEaiJn80LoQJ7APE3vN17b
license: BSD-3-Clause
copyright: Thomas DuBuisson <thomas.dubuisson@gmail.com>
maintainer: Thomas DuBuisson <thomas.dubuisson@gmail.com>
author: Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability: stable
homepage: http://trac.haskell.org/crypto-api/wiki
synopsis: A test framework and KATs for cryptographic operations.
description:
    A test framework for hash and cipher operations using
    the crypto-api interface.  Known answer tests (KATs)
    for common cryptographic algorithms are included.
    Patches welcome (both adding KATs for more algorithms
    or property tests for classes of algorithms).
category: Data, Cryptography
abi: 6878da046bbfbbb31c20def105d144a3
exposed: True
exposed-modules:
    Test.AES Test.Crypto Test.HMAC Test.MD5 Test.ParseNistKATs Test.SHA
    Test.TwoFish
hidden-modules: Paths_crypto_api_tests
import-dirs: /usr/lib/ghc-8.4.3/site-local/crypto-api-tests-0.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/crypto-api-tests-0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/crypto-api-tests-0.3
hs-libraries: HScrypto-api-tests-0.3-BEaiJn80LoQJ7APE3vN17b
depends:
    HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr base-4.11.1.0
    bytestring-0.10.8.2 cereal-0.5.7.0-GeNBgd8Wa452X4EoKnwsnC
    crypto-api-0.13.3-H6IfzwtYtsODXXfSTi5z5x directory-1.3.1.5
    filepath-1.4.2 test-framework-0.8.2.0-Goo1lQ5v8lSKQXzKjc8cO4
    test-framework-hunit-0.3.0.2-2cuZrcC4fpi8ZHxh6Q4D1X
    test-framework-quickcheck2-0.3.0.5-HOPuSahD2LU2AFVRjsBcKR
abi-depends: HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx=6ff9610fd5e59ec310c47074d0590847
             QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=59a035869ce3bae16d8c8360447f600f
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             cereal-0.5.7.0-GeNBgd8Wa452X4EoKnwsnC=5e7d9231d9563e623638bef60db7e501
             crypto-api-0.13.3-H6IfzwtYtsODXXfSTi5z5x=b38ee8fa4c1e132a024035423192fcff
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             test-framework-0.8.2.0-Goo1lQ5v8lSKQXzKjc8cO4=64a691e8d693925c03bbca87367ae847
             test-framework-hunit-0.3.0.2-2cuZrcC4fpi8ZHxh6Q4D1X=47b4f9d45cd39006a0ceb6cbdc059e99
             test-framework-quickcheck2-0.3.0.5-HOPuSahD2LU2AFVRjsBcKR=4500d7893d601963e358f7ca09ce1d18
haddock-interfaces: /usr/share/doc/haskell-crypto-api-tests/html/crypto-api-tests.haddock
haddock-html: /usr/share/doc/haskell-crypto-api-tests/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
